<?php

/**
 * @file
 * Documentation and code examples for API developers.
 */

/**
 * Displays a message about Straton's character (the web and mobile team member
 * on Blizzard's forums). As the character doesn't actually exist, this example
 * will not work however.
 *
 * When using this module, developers may use any functions that follow the
 * blizzardapi_get_* format, with the exception of blizzardapi_get_resource().
 * Only use that function if Blizzard implements a new API resource and this
 * module does not provide a wrapper.
 */
function blizzardapi_example() {
  // In order to get data from realms outside the US region, and in a language
  // other than english, custom options must be sent.
  // All API functions accept these two fields. Some also accept 'skip_cache'
  // and 'expire' fields. See function documentation for more details.
  $options = array(
    'region' => 'eu',
    'language' => 'fr'
  );
  
  // This particular API function also accepts additional character fields. They
  // are used to get the character's guild name and health pool in this case.
  $character = blizzardapi_get_character('PTR', 'Straton', array('guild', 'stats'), $options);
  
  if (isset($character['error'])) {
    // If something went wrong the array will contain both 'error' and 'reason'
    // fields to help you determine a cause.
    drupal_set_message(t('Unable to retrieve character information.'), 'error');
  }
  else {
    $blue = $character['data'];
    $t_args = array(
      '@name'  => $blue['name'],
      '@level' => $blue['level'],
      '@guild' => $blue['guild']['name'],
      '@hp'    => $blue['stats']['health']
    );
    drupal_set_message(t('@name (level @level) belongs to the guild <@guild> and has @hp health.', $t_args));
  }
  
  // If this were a working example, the viewer should see something similar to:
  // "Straton (level 85) belongs to the guild <Blizzard Entertainment> and has 123456 health."
}
